==> xplanetfx-2.6.13_all.tar.gz: usr/share/xplanetFX/languages/hu.py <==

# coding: UTF-8

# Copyright (C) 2010 Markus Schmidt <schmidt@boomshop.net>
# Translation (C) 2013-2014 by Péter Gábor <ptrg>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 1, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Dear translator,
#
# if there are spaces at the beginning of the strings, they're essential!
# Please choose the same length of the strings if possible to avoid destroying
# the interface.
# Thank you for your work!

locale = "hu"
language = "Magyar"

class dictionary:

    splash_theme_list = "Olvasás %s"
    splash_theme_view = "Téma nézet (%s | %s)"
    splash_flip_view = "Flip nézet (%s | %s)"
    splash_pixmaps = "Interaktív kütyük (%d/%d)"
    splash_window = "Ablak beállítása..."

    # NOTEBOOK

    label_themes = "Témák"
    label_settings = "Beállítások"
    label_tools = "Eszközök"
    label_display = "Megjelenítés"
    label_viewn = "Nézet"
    label_services = "Szolgáltatások"

    # SETTINGS

    label_size = """<b>Képernyő</b>
Asztal mérete képpontokban"""
    label_view = """<b>Cél</b>
Megjelenített hely"""
    label_orbit = """<b>Keringés</b>
A Nap követése
(A csúszka beállítja a nézet
elfordulási szögét)"""
    label_city = """Város kiválasztása"""
    label_refresh = """<b>Frissítés</b>
Alvásidő két kép
létrehozása között"""
    label_delay = """<b>Késleltetés</b>
Az automatikus indítás
utáni késleltetés"""
    label_longitude = "<b>Hosszúság</b>"
    label_latitude = "<b>Szélesség</b>"
    label_random = "Véletlen"

    label_date = """<b>Dátum</b>
Adott időpont megjelenítése"""

    label_date_year = "Év"
    label_date_month = "Hónap"
    label_date_day = "Nap"
    label_date_hour = "Óra"
    label_date_minute = "Perc"
    label_date_zone = "Zóna"
    label_fit = "Képernyő mérete"
    label_active = "Aktív"
    label_inactive = "Inaktív"

    label_output = """<b>Kimenet</b>
Fájl vagy asztali környezet"""
    label_script = """<b>Parancsfájl</b>
Feldolgozás után futtatandó"""
    label_script_pre = """<b>Parancsfájl</b>
Feldolgozás előtt futtatandó"""

    label_search_online = "Keresés a böngészőben"

    output_file = "Fájl"
    output_none = "Nincs!"

    label_notify = """<b>Értesítések</b>
GNOME felhasználók értesítése
OSD-vel (libnotify szükséges)"""

    label_tray = """<b>Tálcaikon</b>
Tálcaikon megjelenítése a nézet
és az állapot változtatásához"""
    label_tray_blink = """<b>Villogó ikon</b>
A tálcaikon villog amíg
az xplanetFX dolgozik"""

    label_battery = """<b>Akkumulátor</b>
Ne dolgozzon amíg a rendszer
akkumulátort használ"""

    # SERVICES

    label_xc = """<b>Xplanetclouds.com</b>
Rendszeresen frissített
felhőképek használata a
<a href="http://xplanetclouds.com" title="Regisztrálj az xplanetclouds.com oldalon!">xplanetclouds.com</a> oldalról
(Fizetős szolgáltatás!)"""
    label_xc_user = "Név:"
    label_xc_pass = "Jelszó:"
    xc_hi_q = "4096x2048"
    xc_lo_q = "2048x1024"

    label_nbmc = """<b>NASA Blue Marble
Collection</b>
Havonta változó képek
használata a <a href="http://visibleearth.nasa.gov/view_set.php?categoryID=2355" title="Látogasd meg a NASA Blue Mable Collection oldalát!">NASA.gov</a>
oldaláról"""
    label_install = "Telepítés"
    label_uninstall="Eltávolítás"
    label_cancel="Mégsem"
    status_installing_nbmc="A NASA Blue Marble Collection telepítése (További információk a \"Eszközök\" lapon)..."
    label_nbmc_not_available = "<b>Nincs telepítve!</b>"
    label_nbmc_installing="""<b>A NASA Blue Marble Collection telepítése...</b>
(Ez eltarthat egy ideig az internetkapcsolattól függően,
további információk a "Eszközök" lapon)"""

    # THEMESTORE

    label_theme = "<b>Téma: %s</b>"
    label_style = "Stílus: %s"
    label_new = "<b>Új!</b>"
    label_installed = "(telepítve)"
    label_update_avail = "<span color=\"white\"><b>Frissítés!</b></span>"

    search_online = "Témák keresése a világhálón"
    end_online_search = "Vissza a témaválasztáshoz"
    label_no_timestamp = "Nincs időbélyeg!"

    open_theme_file = "Téma fájl importálása..."
    theme_files = "Téma fájlok"
    all_files = "Minden fájl"
    title_not_readable = "Olvashatatlan fájl"
    message_not_readable = "Sajnos, a fájl amit megadtál nem olvasható"
    title_confirm_delete = "Törlés jóváhagyása"
    message_confirm_delete = """Ez törli az összes stílust is ami a témával jött! Rendben?"""
    active = "<span color=\"white\">AKTÍV</span>"
    title_not_deletable = "Megszakítva"
    message_not_deletable="Az aktuális téma és az alapértelmezett sablon nem törölhető."

    # DISPLAY

    label_earth_size = """<b>Föld mérete</b>"""
    label_earth_pos = """<b>Föld helye</b>
A Föld helye a képernyőn"""
    label_corona = """<b>Korona mérete</b>"""
    label_blur = """<b>Korona halványulása</b>"""
    label_cloud = """<b>Felhők távolsága</b>"""
    label_stars = """<b>Csillagok FOV</b>"""
    label_fx = "<b>Hatások</b>"

    label_background = """Egyéni háttér"""
    label_overlay = """Egyéni lefedőkép"""
    label_overlay_active = """☑"""
    label_overlay_inactive = """☐"""
    open_image_file = "Kép választása..."
    image_files = "Kép fájlok"
    status_install_image = "%s telepítése..."
    status_overlay = "Lefedőkép"
    status_background = "Háttérkép"

    # STATUSBAR

    status_sleeping = "xplanetFX alszik (PID: %s)"
    status_active = "<b>xplanetFX dolgozik</b> (PID: %s)"
    status_stopped = "xplanetFX inaktív"
    status_done = "Kész."
    status_apply_theme = "Váltás erre: %s | %s..."
    status_install_theme = "Téma telepítése: \"%s\"..."
    status_install_themes = "%i téma telepítése..."
    status_downloading_theme = "Téma letöltése: \"%s\": %i%%"
    status_more = " (%s sorbaállítva)"
    status_save_config = "Beállítások mentése..."
    status_unknown_de = "Ismeretlen asztali környezet."
    status_connecting = "Lista lekérése a kiszolgálóról..."
    status_connected = "Témák listája lekérve"
    status_poollist_read = "Témák kijelölve (%s telepítendő)"
    status_none = "nincs"
    status_disconnected = "Kapcsolat lezárva"
    status_connection_failed = "A kapcsolat váratlanul megszakadt!"
    status_updates = " <b>%i frissítés elérhető!</b>"
    status_canceled = "\"%s\" letöltése megszakítva."

    # TOOLS

    autostart_active = "<b>Automatikus indítás bekapcsolva:</b> Az xplanetFX automatikusan elindul és létrehozza az első képet a \"Beállítások\" oldalon megadott \"Késleltetés\" idő után."
    autostart_inactive = "<b>Automatikus indítás kikapcsolva:</b> Az xplanetFX nem indul el automatikusan, hanem kézzel kell elindítani."

    label_clouds = "<b>Felhőkép frissítése:</b> Használd ezt a felhőképek eltávolítására. Erre szükség lehet ha egy letöltött fájl sérült és a felhők hibásan jelennek meg. Az xplanetFX a következő körben újra letölti őket."
    label_log_view="<b>Az xplanetFX aktivitása:</b>"
    label_single="<b>Kép mentése:</b> Kép létrehozása a beállítások alapján és mentése egy megadott helyre. A futó xplanetFX le lesz állítva és nem indul újra magától."
    label_update_templates="<b>Sablonok frissítése:</b> Sablonok keresése és az összes frissítés automatikus letöltése."""
    label_language = """<b>Nyelv</b>
A GUI nyelvének beállítása"""

    save_image_file = "Képfájl mentése..."
    image_files = "Kép fájlok"

    title_confirm_delete_clouds = "Törlés jóváhagyása"
    message_confirm_delete_clouds = """Valóban törölhető a felhőkép?"""

    title_confirm_delete_log = "Törlés jóváhagyása"
    message_confirm_delete_log = """Valóban törölhető a naplózás?"""

    log_empty = "Nem található a naplózás."

    # UPDATER

    updater_title_none = "Nincs elérhető frissítés az xplanetFX-hez."
    updater_title_one = "Egy frissítés érhető el az xplanetFX-hez."
    updater_title_more = "%i  frissítés érhető el az xplanetFX-hez."

    label_updater_update_0 = "<b>Nincs frissítés.</b>"
    label_updater_update_1 = "<b>Egy frissítés!</b> (%sB)\n%s"
    label_updater_update_2 = "<b>%i frissítés!</b> (%sB)\n%s"
    label_updater_nots_0 = "<b>Egy sincs időbélyeg nélkül!</b>"
    label_updater_nots_1 = "<b>Egy időbélyeg nélkül!</b> (%sB)\n%s"
    label_updater_nots_2 = "<b>%i időbélyeg nélkül!</b> (%sB)\n%s"
    label_updater_new_0 = "<b>Nincs új téma.</b>"
    label_updater_new_1 = "<b>Egy új téma!</b> (%sB)\n%s"
    label_updater_new_2 = "<b>%i új téma!</b> (%sB)\n%s"

    # TRAY ICON

    tray_tooltip_0 = """<b>xplanetFX deaktíválva</b>
Kattints az ikonra az aktiváláshoz."""
    tray_tooltip_1 = """<b>xplanetFX alszik</b>
Kattints az ikonra a leállításhoz.
Következő frissítés: %s"""
    tray_tooltip_2 = """<b>xplanetFX dolgozik</b>
Kattints az ikonra a leállításhoz."""

    # OUTPUT SETTINGS
    settings_XFCE_title = "XFCE Beállítások"
    settings_XFCE_header = """<b>XFCE-Beállítások</b>
Válaszd ki a munkaterületeket az xplanetFX számára"""
    settings_XFCE_single = "Erőltesse az egy munkaterület módot (minden munkaterület egyformán lesz beállítva)"
    settings_XFCE_toggle = "☑"
    settings_XFCE_monitor = "Monitor"
    settings_XFCE_workspace = "Munkaterület"

==> xplanetfx-2.6.14_all.tar.gz: usr/share/xplanetFX/languages/hu.py <==

# coding: UTF-8

# Copyright (C) 2010 Markus Schmidt <schmidt@boomshop.net>
# Translation (C) 2013-2014 by Péter Gábor <ptrg>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 1, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Dear translator,
#
# if there are spaces at the beginning of the strings, they're essential!
# Please choose the same length of the strings if possible to avoid destroying
# the interface.
# Thank you for your work!

locale = "hu"
language = "Magyar"

class dictionary:

    splash_theme_list = "Olvasás %s"
    splash_theme_view = "Téma nézet (%s | %s)"
    splash_flip_view = "Flip nézet (%s | %s)"
    splash_pixmaps = "Interaktív kütyük (%d/%d)"
    splash_window = "Ablak beállítása..."

    # NOTEBOOK

    label_themes = "Témák"
    label_settings = "Beállítások"
    label_tools = "Eszközök"
    label_display = "Megjelenítés"
    label_viewn = "Nézet"
    label_services = "Szolgáltatások"

    # SETTINGS

    label_size = """<b>Képernyő</b>
Asztal mérete képpontokban"""
    label_view = """<b>Cél</b>
Megjelenített hely"""
    label_orbit = """<b>Keringés</b>
A Nap követése
(A csúszka beállítja a nézet
elfordulási szögét)"""
    label_city = """Város kiválasztása"""
    label_refresh = """<b>Frissítés</b>
Alvásidő két kép
létrehozása között"""
    label_delay = """<b>Késleltetés</b>
Az automatikus indítás
utáni késleltetés"""
    label_longitude = "<b>Hosszúság</b>"
    label_latitude = "<b>Szélesség</b>"
    label_random = "Véletlen"

    label_date = """<b>Dátum</b>
Adott időpont megjelenítése"""

    label_date_year = "Év"
    label_date_month = "Hónap"
    label_date_day = "Nap"
    label_date_hour = "Óra"
    label_date_minute = "Perc"
    label_date_zone = "Zóna"
    label_fit = "Képernyő mérete"
    label_active = "Aktív"
    label_inactive = "Inaktív"

    label_output = """<b>Kimenet</b>
Fájl vagy asztali környezet"""
    label_script = """<b>Parancsfájl</b>
Feldolgozás után futtatandó"""
    label_script_pre = """<b>Parancsfájl</b>
Feldolgozás előtt futtatandó"""

    label_search_online = "Keresés a böngészőben"

    output_file = "Fájl"
    output_none = "Nincs!"

    label_notify = """<b>Értesítések</b>
GNOME felhasználók értesítése
OSD-vel (libnotify szükséges)"""

    label_tray = """<b>Tálcaikon</b>
Tálcaikon megjelenítése a nézet
és az állapot változtatásához"""
    label_tray_blink = """<b>Villogó ikon</b>
A tálcaikon villog amíg
az xplanetFX dolgozik"""

    label_battery = """<b>Akkumulátor</b>
Ne dolgozzon amíg a rendszer
akkumulátort használ"""

    # SERVICES

    label_xc = """<b>Xplanetclouds.com</b>
Rendszeresen frissített
felhőképek használata a
<a href="http://xplanetclouds.com" title="Regisztrálj az xplanetclouds.com oldalon!">xplanetclouds.com</a> oldalról
(Fizetős szolgáltatás!)"""
    label_xc_user = "Név:"
    label_xc_pass = "Jelszó:"
    xc_hi_q = "4096x2048"
    xc_lo_q = "2048x1024"

    label_nbmc = """<b>NASA Blue Marble
Collection</b>
Havonta változó képek
használata a <a href="http://visibleearth.nasa.gov/view_set.php?categoryID=2355" title="Látogasd meg a NASA Blue Mable Collection oldalát!">NASA.gov</a>
oldaláról"""
    label_install = "Telepítés"
    label_uninstall="Eltávolítás"
    label_cancel="Mégsem"
    status_installing_nbmc="A NASA Blue Marble Collection telepítése (További információk az \"Eszközök\" lapon)..."
    label_nbmc_not_available = "<b>Nincs telepítve!</b>"
    label_nbmc_installing="""<b>A NASA Blue Marble Collection telepítése...</b>
(Ez eltarthat egy ideig az internetkapcsolattól függően,
további információk az "Eszközök" lapon)"""

    # THEMESTORE

    label_theme = "<b>Téma: %s</b>"
    label_style = "Stílus: %s"
    label_new = "<b>Új!</b>"
    label_installed = "(telepítve)"
    label_update_avail = "<span color=\"white\"><b>Frissítés!</b></span>"

    search_online = "Témák keresése a világhálón"
    end_online_search = "Vissza a témaválasztáshoz"
    label_no_timestamp = "Nincs időbélyeg!"

    open_theme_file = "Téma fájl importálása..."
    theme_files = "Téma fájlok"
    all_files = "Minden fájl"
    title_not_readable = "Olvashatatlan fájl"
    message_not_readable = "Sajnos, a fájl amit megadtál nem olvasható"
    title_confirm_delete = "Törlés jóváhagyása"
    message_confirm_delete = """Ez törli az összes stílust is ami a témával jött! Rendben?"""
    active = "<span color=\"white\">AKTÍV</span>"
    title_not_deletable = "Megszakítva"
    message_not_deletable="Az aktuális téma és az alapértelmezett sablon nem törölhető."

    # DISPLAY

    label_earth_size = """<b>Föld mérete</b>"""
    label_earth_pos = """<b>Föld helye</b>
A Föld helye a képernyőn"""
    label_corona = """<b>Korona mérete</b>"""
    label_blur = """<b>Korona halványulása</b>"""
    label_cloud = """<b>Felhők távolsága</b>"""
    label_stars = """<b>Csillagok FOV</b>"""
    label_fx = "<b>Hatások</b>"

    label_background = """Egyéni háttér"""
    label_overlay = """Egyéni lefedőkép"""
    label_overlay_active = """☑"""
    label_overlay_inactive = """☐"""
    open_image_file = "Kép választása..."
    image_files = "Kép fájlok"
    status_install_image = "%s telepítése..."
    status_overlay = "Lefedőkép"
    status_background = "Háttérkép"

    # STATUSBAR

    status_sleeping = "xplanetFX alszik (PID: %s)"
    status_active = "<b>xplanetFX dolgozik</b> (PID: %s)"
    status_stopped = "xplanetFX inaktív"
    status_done = "Kész."
    status_apply_theme = "Váltás erre: %s | %s..."
    status_install_theme = "Téma telepítése: \"%s\"..."
    status_install_themes = "%i téma telepítése..."
    status_downloading_theme = "Téma letöltése: \"%s\": %i%%"
    status_more = " (%s sorbaállítva)"
    status_save_config = "Beállítások mentése..."
    status_unknown_de = "Ismeretlen asztali környezet."
    status_connecting = "Lista lekérése a kiszolgálóról..."
    status_connected = "Témák listája lekérve"
    status_poollist_read = "Témák kijelölve (%s telepítendő)"
    status_none = "nincs"
    status_disconnected = "Kapcsolat lezárva"
    status_connection_failed = "A kapcsolat váratlanul megszakadt!"
    status_updates = " <b>%i frissítés elérhető!</b>"
    status_canceled = "\"%s\" letöltése megszakítva."

    # TOOLS

    autostart_active = "<b>Automatikus indítás bekapcsolva:</b> Az xplanetFX automatikusan elindul és létrehozza az első képet a \"Beállítások\" oldalon megadott \"Késleltetés\" idő után."
    autostart_inactive = "<b>Automatikus indítás kikapcsolva:</b> Az xplanetFX nem indul el automatikusan, hanem kézzel kell elindítani."

    label_clouds = "<b>Felhőkép frissítése:</b> Használd ezt a felhőképek eltávolítására. Erre szükség lehet ha egy letöltött fájl sérült és a felhők hibásan jelennek meg. Az xplanetFX a következő körben újra letölti őket."
    label_log_view="<b>Az xplanetFX aktivitása:</b>"
    label_single="<b>Kép mentése:</b> Kép létrehozása a beállítások alapján és mentése egy megadott helyre. A futó xplanetFX le lesz állítva és nem indul újra magától."
    label_update_templates="<b>Sablonok frissítése:</b> Sablonok keresése és az összes frissítés automatikus letöltése."""
    label_language = """<b>Nyelv</b>
A GUI nyelvének beállítása"""

    save_image_file = "Képfájl mentése..."
    image_files = "Kép fájlok"

    title_confirm_delete_clouds = "Törlés jóváhagyása"
    message_confirm_delete_clouds = """Valóban törölhető a felhőkép?"""

    title_confirm_delete_log = "Törlés jóváhagyása"
    message_confirm_delete_log = """Valóban törölhető a naplózás?"""

    log_empty = "Nem található a naplózás."

    # UPDATER

    updater_title_none = "Nincs elérhető frissítés az xplanetFX-hez."
    updater_title_one = "Egy frissítés érhető el az xplanetFX-hez."
    updater_title_more = "%i  frissítés érhető el az xplanetFX-hez."

    label_updater_update_0 = "<b>Nincs frissítés.</b>"
    label_updater_update_1 = "<b>Egy frissítés!</b> (%sB)\n%s"
    label_updater_update_2 = "<b>%i frissítés!</b> (%sB)\n%s"
    label_updater_nots_0 = "<b>Egy sincs időbélyeg nélkül!</b>"
    label_updater_nots_1 = "<b>Egy időbélyeg nélkül!</b> (%sB)\n%s"
    label_updater_nots_2 = "<b>%i időbélyeg nélkül!</b> (%sB)\n%s"
    label_updater_new_0 = "<b>Nincs új téma.</b>"
    label_updater_new_1 = "<b>Egy új téma!</b> (%sB)\n%s"
    label_updater_new_2 = "<b>%i új téma!</b> (%sB)\n%s"

    # TRAY ICON

    tray_tooltip_0 = """<b>xplanetFX deaktíválva</b>
Kattints az ikonra az aktiváláshoz."""
    tray_tooltip_1 = """<b>xplanetFX alszik</b>
Kattints az ikonra a leállításhoz.
Következő frissítés: %s"""
    tray_tooltip_2 = """<b>xplanetFX dolgozik</b>
Kattints az ikonra a leállításhoz."""

    # OUTPUT SETTINGS
    settings_XFCE_title = "XFCE Beállítások"
    settings_XFCE_header = """<b>XFCE-Beállítások</b>
Válaszd ki a munkaterületeket az xplanetFX számára"""
    settings_XFCE_single = "Erőltesse az egy munkaterület módot (minden munkaterület egyformán lesz beállítva)"
    settings_XFCE_toggle = "☑"
    settings_XFCE_monitor = "Monitor"
    settings_XFCE_workspace = "Munkaterület"
